@@ -31,6 +31,7 @@ func newUpdate() *cobra.Command {
 
 	flag.Add(
 		cmd,
+		flag.Image(),
 		sharedFlags,
 	)
 
@@ -63,29 +64,34 @@ func runUpdate(ctx context.Context) (err error) {
 		return err
 	}
 
+	imageOrPath := machine.Config.Image
+	image := flag.GetString(ctx, flag.ImageName)
+	dockerfile := flag.GetString(ctx, flag.Dockerfile().Name)
+	if len(image) > 0 {
+		imageOrPath = image
+	} else if len(dockerfile) > 0 {
+		imageOrPath = "." // cwd
+	}
+
 	prevInstanceID := machine.InstanceID
 
 	fmt.Fprintf(io.Out, "Machine %s was found and is currently in a %s state, attempting to update...\n", machineID, machine.State)
 
+	machineConf := *machine.Config
+	machineConf, err = determineMachineConfig(ctx, machineConf, app, imageOrPath)
+	if err != nil {
+		return
+	}
+
 	input := api.LaunchMachineInput{
 		ID:     machine.ID,
 		AppID:  app.Name,
 		Name:   machine.Name,
 		Region: machine.Region,
+		Config: &machineConf,
 	}
 
-	machineConf := *machine.Config
-
-	machineConf, err = determineMachineConfig(ctx, machineConf, app, machine.Config.Image)
-
-	if err != nil {
-		return
-	}
-
-	input.Config = &machineConf
-
 	machine, err = flapsClient.Update(ctx, input, "")
-
 	if err != nil {
 		return err
 	}
@@ -105,7 +111,7 @@ func runUpdate(ctx context.Context) (err error) {
 		return err
 	}
 
-	fmt.Fprintf(out, "Image: %s\n", machine.Config.Image)
+	fmt.Fprintf(out, "Image: %s\n", machineConf.Image)
 
 	if waitForAction == "start" {
 		fmt.Fprintf(out, "State: Started\n\n")
